@@ -72,6 +72,7 @@ __all__ = [
 		"HasHead",
 		"String",
 		"FrameOrSeries",
+		"SupportsIndex",
 		]
 
 #: Type hint for objects that represent filesystem paths.
@@ -121,7 +122,7 @@ class JsonLibrary(Protocol):
 			**kwds: Any,
 			) -> str:
 		"""
-		Serialize ``obj`` to a JSON formatted ``str``.
+		Serialize ``obj`` to a JSON formatted :class:`str`.
 
 		:param obj:
 		:param skipkeys:
@@ -165,9 +166,9 @@ class JsonLibrary(Protocol):
 #  Backported from https://github.com/python/cpython/blob/master/Lib/types.py
 #  Licensed under the Python Software Foundation License Version 2.
 #  Copyright © 2001-2020 Python Software Foundation. All rights reserved.
-#  Copyright © 2000 BeOpen.com . All rights reserved.
-#  Copyright © 1995-2000 Corporation for National Research Initiatives . All rights reserved.
-#  Copyright © 1991-1995 Stichting Mathematisch Centrum . All rights reserved.
+#  Copyright © 2000 BeOpen.com. All rights reserved.
+#  Copyright © 1995-2000 Corporation for National Research Initiatives. All rights reserved.
+#  Copyright © 1991-1995 Stichting Mathematisch Centrum. All rights reserved.
 
 WrapperDescriptorType = type(object.__init__)
 MethodWrapperType = type(object().__str__)
@@ -192,12 +193,12 @@ class String(Protocol):
 @runtime_checkable
 class HasHead(Protocol):
 	"""
-	.. versionadded:: 0.8.0
-
 	:class:`typing.Protocol` for classes that have a ``head`` method.
 
 	This includes :class:`pandas.DataFrame` and :class:`pandas.Series`.
-	"""
+
+	.. versionadded:: 0.8.0
+	"""  # noqa D400
 
 	def head(self: "FrameOrSeries", n: int = 5) -> "FrameOrSeries":
 		"""
@@ -218,3 +219,14 @@ class HasHead(Protocol):
 #
 # 	def __lt__(self, other: Any) -> bool:
 # 		...  # pragma: no cover
+
+
+class SupportsIndex(Protocol):
+	"""
+	:class:`typing.Protocol` for classes that support ``__index__``.
+
+	.. versionadded:: 2.0.0
+	"""
+
+	def __index__(self) -> int:  # pragma: no cover
+		...
